#!/bin/bash

# Update and install base packages
sudo pacman -Syu
sudo pacman -Sy xorg-xsetroot alacritty ttf-firacode-nerd noto-fonts gnome-keyring playerctl scrot xsecurelock # DE Setup
sudo pacman -Sy neovim vifm neofetch fish htop networkmanager networkmanager-openvpn unzip ripgrep lldb # Utilities 
sudo pacman -Sy base-devel rustup go fzf cmake docker   # Dev
sudo pacman -Sy spotifyd discord # Userspace

# Move relevant script and config files
ln -s  ~/.config/.xinitrc ~/.xinitrc
mkdir ~/.dwm
ln -s ~/.config/scripts/autostart.sh ~/.dwm/autostart.sh 

# Change Shell
chsh -s /usr/bin/fish

# Install rust (Used for Lemurs)
rustup install stable

# Install AUR:w
cd /opt
sudo git clone https://aur.archlinux.org/yay.git
sudo chown -R luke-else:users ./yay

cd yay
makepkg -si

cd ~

# Install packages through AUR
yay brave-bin

# Install and Configure git elements
mkdir ~/git
cd ~/git 

git config --global user.name 'Luke Else'
git config --global user.email 'mail@luke-else.co.uk'

git clone ssh://git@git.luke-else.co.uk:222/luke-else/dwm.git
git clone ssh://git@git.luke-else.co.uk:222/luke-else/dmenu.git
git clone ssh://git@git.luke-else.co.uk:222/luke-else/dwmblocks.git
git clone https://github.com/coastalwhite/lemurs

# Install DWM
cd dwm
git checkout dwm-patched
sudo make install
cd ..

# Install dmenu
cd dmenu
sudo make install
cd ..

# Install DWMBlocks
cd dwmblocks
sudo make install
sudo mkdir -p /usr/bin/
sudo ln -s ~/git/dwmblocks/statusbar/* /usr/bin/
cd ..

# Install Lemurs
cd lemurs
sudo chmod +x install.sh
./install.sh
sudo ln -s  ~/.config/.xinitrc /etc/lemurs/wms/dwm
cd ..

# Install Oh-My-FISH
cd ~
curl https://raw.githubusercontent.com/oh-my-fish/oh-my-fish/master/bin/install | fish

# Install Packer.nvim

git clone --depth 1 https://github.com/wbthomason/packer.nvim\
 ~/.local/share/nvim/site/pack/packer/start/packer.nvim
